@@ -68,6 +68,6 @@ class convertEnv():
             if k in self.convertData:
                 service = self.convertData[k]['service']
                 service_key = self.convertData[k]['replace']
-                value = convertStrListDict(v.encode('utf-8'))
+                value = convertStrListDict(v)
                 convert_vars[service][service_key] = value
         return convert_vars
