@@ -842,7 +842,7 @@ class Git():
         git_dir = self._gitDir(rpath)
         git_tag = self.process(self._git, "--git-dir", git_dir, "--work-tree",
                                rpath,
-                               "describe", "--tags", stderr=STDOUT)
+                               "describe", "--tags", "--abbrev=0", stderr=STDOUT)
         if git_tag.success():
             return git_tag.read().strip()
         return ""
